@@ -32,6 +32,10 @@ tsfeatures <- function(tslist,
   else{
     tslist <- map(tslist, as.ts)
   }
+  if (scale && any(map_dbl(tslist, var, na.rm=TRUE) == 0)){
+    warning("Some series are constant and cannot be scaled, so scaling has been disabled (`scale = FALSE`).")
+    scale <- FALSE
+  }
   if (scale) {
     tslist <- map(tslist, scalets)
   }
@@ -53,17 +57,19 @@ tsfeatures <- function(tslist,
     on.exit(future::plan(old_plan))
   }
   for (i in seq_along(features)) {
-    
+
     if (parallel) {
       flist[[i]] <- furrr::future_map(tslist, func[[i]], ...)
     }
     else {
       flist[[i]] <- map(tslist, func[[i]], ...)
     }
-   
 
     # Check names
     if (is.null(names(flist[[i]][[1]]))) {
+      if(length(flist[[i]][[1]]) != 1L) {
+        stop(paste("Function",features[i],"not returning named feature vector"))
+      }
       flist[[i]] <- map(
         flist[[i]],
         function(x) {
@@ -104,6 +110,9 @@ tsfeatures <- function(tslist,
 # Scale time series
 scalets <- function(x) {
   n <- length(x)
+  if (forecast::is.constant(x)) {
+    return(x)
+  }
   scaledx <- as.numeric(scale(x, center = TRUE, scale = TRUE))
   if ("msts" %in% class(x)) {
     msts <- attributes(x)$msts
@@ -123,9 +132,6 @@ trimts <- function(x, trim = 0.1) {
   return(x)
 }
 
-
-
-
 # check for duplicate feature names in the feature list and rename by prepending
 # the name of the function that generates them to avoid conflicts: "functionName_featureName"
 # both functions' features are renamed
